PinMetaQuery class

Pin Meta Query

Can be used to query pins based on fields / target. Create queries by running PinMeta query operations.

final query = PinMeta.at('type').greaterThan(2);

Properties

hashCode int
The hash code for this object.
no setterinherited
operation String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String
final
value1 Object
final
value2 Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited