PinMetaQuery class
Pin Meta Query
Can be used to query pins based on fields /
target. Create queries by running PinMeta
query operations.
final query = PinMeta.at('type').greaterThan(2);
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited